Index: tmp/org.txm.cooccurrence.chartsengine/src/org/txm/cooccurrence/functions/CooccurrenceGraph.java
===================================================================
--- tmp/org.txm.cooccurrence.chartsengine/src/org/txm/cooccurrence/functions/CooccurrenceGraph.java	(revision 1388)
+++ tmp/org.txm.cooccurrence.chartsengine/src/org/txm/cooccurrence/functions/CooccurrenceGraph.java	(revision 1389)
@@ -21,7 +21,17 @@
 	 */
 	public CooccurrenceGraph(TXMResult parent) {
 		super(parent);
-		// TODO Auto-generated constructor stub
+		
+		// FIXME: conception problem
+		// Since the command has no preferences, the default charts engine preferences are not loaded in TXMResult constructor, so the code above is needed to reload the parameters
+		this.commandPreferencesNodePath = "org.txm.chartsengine.core";
+		try {
+			this.autoLoadParametersFromAnnotations();
+		}
+		catch (Exception e) {
+			// TODO Auto-generated catch block
+			e.printStackTrace();
+		}
 	}
 
 	/**
@@ -29,7 +39,6 @@
 	 */
 	public CooccurrenceGraph(String parametersNodePath) {
 		super(parametersNodePath);
-		// TODO Auto-generated constructor stub
 	}
 
 
Index: tmp/org.txm.statsengine.r.rcp/src/org/txm/statsengine/r/rcp/handlers/CheckRPackages.java
===================================================================
--- tmp/org.txm.statsengine.r.rcp/src/org/txm/statsengine/r/rcp/handlers/CheckRPackages.java	(revision 1388)
+++ tmp/org.txm.statsengine.r.rcp/src/org/txm/statsengine/r/rcp/handlers/CheckRPackages.java	(revision 1389)
@@ -120,7 +120,7 @@
 					}
 				} else { // package is not present, install it
 					try {
-						System.out.println(TXMCoreMessages.bind("The '{0}' package is not installed. Trying to install it now...", p));
+						Log.info(TXMCoreMessages.bind("The '{0}' package is not installed. Trying to install it now...", p));
 						
 						try {rw.eval("detach(\"package:"+p+"\", character.only = TRUE)");} catch(Exception tmpE){} // unload package to be able to reinstall it //$NON-NLS-1$ //$NON-NLS-2$
 						
Index: tmp/org.txm.chartsengine.graphstream.core/src/org/txm/chartsengine/graphstream/core/GSChartCreator.java
===================================================================
--- tmp/org.txm.chartsengine.graphstream.core/src/org/txm/chartsengine/graphstream/core/GSChartCreator.java	(revision 1388)
+++ tmp/org.txm.chartsengine.graphstream.core/src/org/txm/chartsengine/graphstream/core/GSChartCreator.java	(revision 1389)
@@ -32,11 +32,11 @@
 			System.out.println("GSChartCreator.updateChart() style sheet dump: " + graph.getAttribute("ui.stylesheet"));
 			
 			// Add the current shared preferences as Font size, etc.
-			graph.addAttribute("ui.stylesheet", graph.getAttribute("ui.stylesheet") + "node {"
-					+ " text-size: " + result.getFont().split("\\|")[2] + ";" 
-					+ " text-font: \"" + result.getFont().split("\\|")[1] + "\";" 
-							
-							+ " }");
+//			graph.addAttribute("ui.stylesheet", graph.getAttribute("ui.stylesheet") + "node {"
+//					+ " text-size: " + result.getFont().split("\\|")[2] + ";" 
+//					+ " text-font: \"" + result.getFont().split("\\|")[1] + "\";" 
+//							
+//							+ " }");
 
 			// FIXME: Debug
 			System.out.println("GSChartCreator.updateChart() style sheet dump: " + graph.getAttribute("ui.stylesheet"));
Index: tmp/org.txm.chartsengine.graphstream.core/src/org/txm/chartsengine/graphstream/core/preferences/GSChartsEnginePreferences.java
===================================================================
--- tmp/org.txm.chartsengine.graphstream.core/src/org/txm/chartsengine/graphstream/core/preferences/GSChartsEnginePreferences.java	(revision 1388)
+++ tmp/org.txm.chartsengine.graphstream.core/src/org/txm/chartsengine/graphstream/core/preferences/GSChartsEnginePreferences.java	(revision 1389)
@@ -33,6 +33,7 @@
 	
 	@Override
 	public void initializeDefaultPreferences() {
+		super.initializeDefaultPreferences();
 		Preferences defaultPreferences = this.getDefaultPreferencesNode();
 		defaultPreferences.put(OUTPUT_FORMAT, GSChartsEngine.OUTPUT_FORMAT_GRAPHSTREAM);
 	}
Index: tmp/org.txm.edition.rcp/src/org/txm/edition/rcp/handlers/OpenEdition.java
===================================================================
--- tmp/org.txm.edition.rcp/src/org/txm/edition/rcp/handlers/OpenEdition.java	(revision 1388)
+++ tmp/org.txm.edition.rcp/src/org/txm/edition/rcp/handlers/OpenEdition.java	(revision 1389)
@@ -176,8 +176,7 @@
 			IWorkbenchPage page = window.getActivePage();
 
 			SynopticEditorInput editorInput = new SynopticEditorInput(corpus, text.getName(), editions);
-			SynopticEditionEditor editor = (SynopticEditionEditor) page.openEditor(editorInput,
-					SynopticEditionEditor.ID, true);
+			SynopticEditionEditor editor = (SynopticEditionEditor) page.openEditor(editorInput, SynopticEditionEditor.ID, true);
 
 			return editor;
 
Index: tmp/org.txm.core/src/java/org/txm/Toolbox.java
===================================================================
--- tmp/org.txm.core/src/java/org/txm/Toolbox.java	(revision 1388)
+++ tmp/org.txm.core/src/java/org/txm/Toolbox.java	(revision 1389)
@@ -162,16 +162,21 @@
 	}
 
 
-	public static EnginesManager<? extends Engine> getEngineManager(EngineType et) {
+	/**
+	 * Gets the manager of the specified engine type.
+	 * @param engineType
+	 * @return
+	 */
+	public static EnginesManager<? extends Engine> getEngineManager(EngineType engineType) {
 
 		if (enginesManagers == null) {
 			return null;
 		}
-		return enginesManagers.get(et);
+		return enginesManagers.get(engineType);
 	}
 
 	/**
-	 * 
+	 * Gets the TXM working directory.
 	 * @return the TXM working directory set with the USER_TXM_HOME preference key 
 	 */
 	public static String getTxmHomePath() {
@@ -205,6 +210,12 @@
 		return ret;
 	}
 
+	/**
+	 * 
+	 * @param preferencesStore
+	 * @return
+	 * @throws Exception
+	 */
 	public static boolean initialize(Class preferencesStore) throws Exception {
 		return initialize(preferencesStore, null);
 	}
Index: tmp/org.txm.core/src/java/org/txm/objects/Edition.java
===================================================================
--- tmp/org.txm.core/src/java/org/txm/objects/Edition.java	(revision 1388)
+++ tmp/org.txm.core/src/java/org/txm/objects/Edition.java	(revision 1389)
@@ -405,7 +405,8 @@
 		//System.out.println("USE THE PROJECT IMPORTMODULE TO BUILD THE EDITION="+userName);
 		if (pages == null) {
 			pages = new ArrayList<Page>();
-		} else {
+		}
+		else {
 			pages.clear();
 		}
 		
Index: tmp/org.txm.progression.rcp/src/org/txm/progression/rcp/chartsengine/events/ProgressionEventCallBack.java
===================================================================
--- tmp/org.txm.progression.rcp/src/org/txm/progression/rcp/chartsengine/events/ProgressionEventCallBack.java	(revision 1388)
+++ tmp/org.txm.progression.rcp/src/org/txm/progression/rcp/chartsengine/events/ProgressionEventCallBack.java	(revision 1389)
@@ -31,6 +31,7 @@
 import org.txm.edition.rcp.editors.RGBA;
 import org.txm.edition.rcp.editors.SynopticEditionEditor;
 import org.txm.edition.rcp.handlers.OpenEdition;
+import org.txm.objects.CorpusBuild;
 import org.txm.objects.Edition;
 import org.txm.objects.Page;
 import org.txm.objects.Text;
@@ -88,12 +89,12 @@
 	
 						// Linked edition (CTRL/CMD + double click)
 						if((mouseEvent.getModifiers() & ZoomAndPanCallBack.keyboardZoomModifierKeyMask) != 0) {
-							// Updates the linked editor
+							// Creates or updates the linked editor
 							updateLinkedEditionEditor((SynopticEditionEditor) chartEditor.getLinkedEditor(SynopticEditionEditor.class), selectedPointPositions);
 						}
 						// Linked concordance
 						else	{
-							// Updates the linked editor
+							// Creates or updates the linked editor
 							updateLinkedConcordanceEditor(chartEditor.getLinkedEditors(ConcordanceEditor.class), selectedPointPositions);
 						}
 					}
@@ -131,14 +132,15 @@
 						return;
 					}
 					
-					// Arrow keys
-					if(keyEvent.getKeyCode() == KeyEvent.VK_LEFT || keyEvent.getKeyCode() == KeyEvent.VK_RIGHT)	{
+					// Arrow keys + return key
+					if(keyEvent.getKeyCode() == KeyEvent.VK_LEFT || keyEvent.getKeyCode() == KeyEvent.VK_RIGHT
+							 || keyEvent.getKeyCode() == KeyEvent.VK_ENTER)	{
 					
 						final ArrayList<Integer> selectedPointPositions = ((ProgressionChartCreator) chartEditor.getResult().getChartCreator()).getSelectedPointPositions(chartEditor.getChart());
 	
 						// Get the linked concordance editors and update the one linked to the progression curve if it exists
 						ArrayList<EditorPart> linkedConcordancesEditors = chartEditor.getLinkedEditors(ConcordanceEditor.class);
-						if(!linkedConcordancesEditors.isEmpty())	{
+						if(keyEvent.getKeyCode() == KeyEvent.VK_ENTER || !linkedConcordancesEditors.isEmpty())	{
 							updateLinkedConcordanceEditor(linkedConcordancesEditors, selectedPointPositions);
 						}
 						
@@ -157,7 +159,7 @@
 	
 	
 	/**
-	 * Updates the linked concordance editor.
+	 * Creates or updates the linked concordance editor.
 	 * If the editor doesn't exist it will be created.
 	 * 
 	 * @param linkedEditors
@@ -235,6 +237,7 @@
 					position = EModelService.RIGHT_OF;
 					parentEditor = linkedEditors.get(linkedEditors.size() - 1);
 					
+					// FIXME: Debug
 					System.err.println("ProgressionEventCallBack.updateLinkedConcordanceEditor(): parent editor for splitting: " + parentEditor); //$NON-NLS-1$
 				}
 				// Split and add linked editor
@@ -368,8 +371,8 @@
 			}
 			
 			CQPCorpus corpus = ((Progression) chartEditor.getResult()).getCorpus();
-			StructuralUnit textS = corpus.getStructuralUnit("text"); //$NON-NLS-1$
-			Property textP = textS.getProperty("id"); //$NON-NLS-1$
+			StructuralUnit textS = corpus.getStructuralUnit(CorpusBuild.TEXT);
+			Property textP = textS.getProperty(CorpusBuild.ID);
 			Match selectedWordMatch = new Match(selectedPointPositions.get(selectedPointPositions.size() - 1), selectedPointPositions.get(selectedPointPositions.size() - 1));
 			String textId = selectedWordMatch.getValueForProperty(textP);
 
@@ -386,8 +389,13 @@
 				return;
 			}
 
+			// Compute the edition if needed
+			if(!edition.hasBeenComputedOnce())	{
+				edition.compute();
+			}
+			
 			// Get the current selected word to highlight more
-			List<String> selectedWordIds = selectedWordMatch.getValuesForProperty(corpus.getProperty("id")); //$NON-NLS-1$;
+			List<String> selectedWordIds = selectedWordMatch.getValuesForProperty(corpus.getProperty(CorpusBuild.ID));
 
 			// Get all words to highlight from the progression chart data set
 			ArrayList<ArrayList<Integer>> allPointPositionsBySeries = ((ProgressionChartCreator)chartEditor.getResult().getChartCreator()).getAllPointPositionsBySeries(chartEditor.getChart());
@@ -399,7 +407,7 @@
 				for(int j = 0; j < positions.size(); j++) {
 					Match match = new Match(positions.get(j), positions.get(j));					
 					if(match.getValueForProperty(textP).equals(textId)) {
-						wordsIds.add(match.getValueForProperty(corpus.getProperty("id"))); //$NON-NLS-1$;
+						wordsIds.add(match.getValueForProperty(corpus.getProperty(CorpusBuild.ID))); //$NON-NLS-1$;
 					}
 				}
 				allWordIds.add(wordsIds);
Index: tmp/org.txm.progression.rcp/OSGI-INF/l10n/bundle_fr.properties
===================================================================
--- tmp/org.txm.progression.rcp/OSGI-INF/l10n/bundle_fr.properties	(revision 1388)
+++ tmp/org.txm.progression.rcp/OSGI-INF/l10n/bundle_fr.properties	(revision 1389)
@@ -5,6 +5,6 @@
 
 command.name.3 = Envoyer vers la progression
 
-command.tooltip = Calculer le graphique de progression d'une ou plusieurs requêtes
+command.tooltip = Calculer le graphique de progression d'une ou plusieurs requrequ\u00EAtetes
 
 page.name = Progression
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/AdvancedPreferencePage.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/AdvancedPreferencePage.java	(revision 1388)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/AdvancedPreferencePage.java	(revision 1389)
@@ -115,9 +115,6 @@
 		// Expert mode
 		addField(new BooleanFieldEditor(TBXPreferences.EXPERT_USER, TXMUIMessages.advancedUserMode, getFieldEditorParent()));
 
-		// Auto save each result after computing and auto load them at startup
-		addField(new BooleanFieldEditor(TBXPreferences.AUTO_PERSISTENCE_ENABLED, TXMUIMessages.enableAutomaticSaveOfAllResultsPersistence, getFieldEditorParent()));
-
 	}
 
 	/* (non-Javadoc)

Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/UserPreferencePage.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/UserPreferencePage.java	(revision 1388)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/UserPreferencePage.java	(revision 1389)
@@ -28,13 +28,14 @@
 package org.txm.rcp.preferences;
 
 import org.eclipse.jface.preference.BooleanFieldEditor;
-import org.eclipse.jface.preference.FieldEditorPreferencePage;
-import org.eclipse.ui.IWorkbench;
-import org.eclipse.ui.IWorkbenchPreferencePage;
+import org.txm.core.preferences.TBXPreferences;
 import org.txm.rcp.messages.TXMUIMessages;
-// TODO: Auto-generated Javadoc
 /**
  * The Class UserPreferencePage.
  */
 public class UserPreferencePage extends RCPPreferencesPage {
 
@@ -47,7 +48,12 @@
 
 	@Override
 	protected void createFieldEditors() {
-		addField(new BooleanFieldEditor(RCPPreferences.USER_ALERT_DELETE, TXMUIMessages.doNotConfirmToDeleteAnObject, BooleanFieldEditor.SEPARATE_LABEL, getFieldEditorParent()));
-		addField(new BooleanFieldEditor(RCPPreferences.AUTO_UPDATE_EDITOR, TXMUIMessages.automaticRecomputingWhenChangingAParameter, BooleanFieldEditor.SEPARATE_LABEL, getFieldEditorParent()));
+		this.addField(new BooleanFieldEditor(RCPPreferences.USER_ALERT_DELETE, TXMUIMessages.doNotConfirmToDeleteAnObject, BooleanFieldEditor.SEPARATE_LABEL, this.getFieldEditorParent()));
+
+		// Auto compute the resul when a parameter changes
+		this.addField(new BooleanFieldEditor(RCPPreferences.AUTO_UPDATE_EDITOR, TXMUIMessages.automaticRecomputingWhenChangingAParameter, BooleanFieldEditor.SEPARATE_LABEL, this.getFieldEditorParent()));
+		
+		// Auto save each result after computing and auto load them at startup
+		this.addField(new BooleanFieldEditor(TBXPreferences.AUTO_PERSISTENCE_ENABLED, TXMUIMessages.enableAutomaticSaveOfAllResultsPersistence, BooleanFieldEditor.SEPARATE_LABEL, this.getFieldEditorParent()));
 	}
 }
\ No newline at end of file
@@ -28,13 +28,14 @@
 /**
- * The Class UserPreferencePage.
+ * User preferences page.
+ * 
+ * @author mdecorde
+ * @author sjacquot
+ * 
  */
 public class UserPreferencePage extends RCPPreferencesPage {